"""
Aura logger functions
"""

import logging

from libraries.base.config import AuraConfig


class AuraLogger(AuraConfig):
    logger = None

    def __init__(self):
        super(AuraLogger, self).__init__()
        self.__create_logger("AuraEngine")

    def __create_logger(self, name):
        """
        Creates the logger instance for AuraEngine
        :param name: LoggerName
        :return:
        """
        lvl = self.config.get("loglevel")

        # create logger
        self.logger = logging.getLogger(name)
        self.logger.setLevel(lvl)

        if not self.logger.hasHandlers():
            # create file handler for logger
            file_handler = logging.FileHandler(self.config.get("logdir") + "/engine.log")
            file_handler.setLevel(lvl)

            # create stream handler for logger
            stream_handler = logging.StreamHandler()
            stream_handler.setLevel(lvl)

            # set format of log
            datepart = "%(asctime)s:%(name)s:%(levelname)s"
            message = " - %(message)s - "
            filepart = "[%(filename)s:%(lineno)s-%(funcName)s()]"
            formatter = logging.Formatter(datepart + message + filepart)

            # set log of handlers
            file_handler.setFormatter(formatter)
            stream_handler.setFormatter(formatter)

            # add handlers to the logger
            self.logger.addHandler(file_handler)
            self.logger.addHandler(stream_handler)

            self.logger.critical("ADDED HANDLERS")
        else:
            self.logger.critical("REUSED LOGGER")